Skip to main content
aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorThanh Liem PHAN2017-03-07 15:46:51 +0000
committerGerrit Code Review @ Eclipse.org2017-04-24 14:19:40 +0000
commit54fc6c60773a0b877e128bd02bdb7aa91d41f59e (patch)
tree529953d1cbc684db38b2a7d94f06b055b4133c45 /plugins/views/modelexplorer
parent720535066cbf205dc021d61b131f9cf64e44a244 (diff)
downloadorg.eclipse.papyrus-54fc6c60773a0b877e128bd02bdb7aa91d41f59e.tar.gz
org.eclipse.papyrus-54fc6c60773a0b877e128bd02bdb7aa91d41f59e.tar.xz
org.eclipse.papyrus-54fc6c60773a0b877e128bd02bdb7aa91d41f59e.zip
Bug 355731 - [collaborative work] move element/diagram into a submodel
not loaded should be forbidden - Prohibit the move of an element or a diagram if the target element is a proxy (an object that has not been loaded) Change-Id: I7170a1ce929c2c3a6902c38be2e9e842955ac90b Signed-off-by: Thanh Liem PHAN <thanhliem.phan@all4tec.net>
Diffstat (limited to 'plugins/views/modelexplorer')
-rw-r--r--plugins/views/modelexplorer/org.eclipse.papyrus.views.modelexplorer/src/org/eclipse/papyrus/views/modelexplorer/dnd/CommonDropAdapterAssistant.java6
1 files changed, 3 insertions, 3 deletions
diff --git a/plugins/views/modelexplorer/org.eclipse.papyrus.views.modelexplorer/src/org/eclipse/papyrus/views/modelexplorer/dnd/CommonDropAdapterAssistant.java b/plugins/views/modelexplorer/org.eclipse.papyrus.views.modelexplorer/src/org/eclipse/papyrus/views/modelexplorer/dnd/CommonDropAdapterAssistant.java
index 5e62f70e145..afc7e3ed00a 100644
--- a/plugins/views/modelexplorer/org.eclipse.papyrus.views.modelexplorer/src/org/eclipse/papyrus/views/modelexplorer/dnd/CommonDropAdapterAssistant.java
+++ b/plugins/views/modelexplorer/org.eclipse.papyrus.views.modelexplorer/src/org/eclipse/papyrus/views/modelexplorer/dnd/CommonDropAdapterAssistant.java
@@ -145,9 +145,9 @@ public class CommonDropAdapterAssistant extends org.eclipse.ui.navigator.CommonD
ViewPrototype proto = ViewPrototype.get(view);
- // check if diagram can exist in new location
- if (!proto.isOwnerReassignable() || PolicyChecker.getFor(target).getOwningRuleFor(proto, target) == null) {
- // stop here with unexecutable command
+ // Check if diagram can exist in new location or the target object is a proxy
+ if (!proto.isOwnerReassignable() || PolicyChecker.getFor(target).getOwningRuleFor(proto, target) == null || target.eIsProxy()) {
+ // Stop here with unexecutable command
return UnexecutableCommand.INSTANCE;
}

Back to the top